@@ -1,27 +1,34 @@
+# $Id: /mirror/perl/Data-Decode/trunk/lib/Data/Decode/Chain.pm 4834 2007-11-03T09:22:42.139028Z daisuke  $
+#
+# Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
+# All rights reserved.
 
 package Data::Decode::Chain;
-use Moose;
-use MooseX::AttributeHelpers;
-use namespace::clean -except => qw(meta);
+use strict;
+use warnings;
+use base qw(Class::Accessor::Fast);
 use Data::Decode::Exception;
-use Data::Decode::Types;
 
-has decoders => (
-    metaclass => 'Collection::Array',
-    is => 'ro',
-    isa => 'Data::Decode::DecoderList',
-    required => 1,
-    coerce => 1,
-    provides => {
-        elements => 'all_decoders',
+__PACKAGE__->mk_accessors($_) for qw(decoders);
+
+sub new
+{
+    my $class = shift;
+    my %args  = @_;
+    $args{decoders} ||= [];
+    if (ref $args{decoders} ne 'ARRAY') {
+        $args{decoders} = [ $args{decoders} ];
     }
-);
 
-sub decode {
+    return $class->SUPER::new({ decoders => $args{decoders} });
+}
+
+sub decode
+{
     my ($self, $decoder, $string, $hints) = @_;
 
     my $ret;
-    foreach my $decoder ($self->all_decoders) {
+    foreach my $decoder (@{ $self->decoders }) {
         $ret = eval {
             $decoder->decode($decoder, $string, $hints);
         };
